module.exports={A:{A:{"2":"I D fB","4":"E F A B"},B:{"4":"C J K L M N O R S T U V W X P Y Z G"},C:{"4":"0 1 2 3 4 5 6 7 8 9 gB VB H a I D E F A B C J K L M N O b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G iB jB"},D:{"4":"0 1 2 3 4 5 6 7 8 9 H a I D E F A B C J K L M N O b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB"},E:{"2":"nB bB","4":"H a I D E F A B C J K oB pB qB rB cB TB UB sB tB uB"},F:{"2":"F","4":"0 1 2 3 4 5 6 7 8 9 B C L M N O b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB vB wB xB yB TB dB zB UB"},G:{"4":"E bB 0B eB 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC"},H:{"4":"JC"},I:{"2":"VB H KC LC MC NC eB","4":"G OC PC"},J:{"2":"D A"},K:{"4":"A B C Q TB dB UB"},L:{"4":"G"},M:{"4":"P"},N:{"4":"A B"},O:{"2":"QC"},P:{"4":"H RC SC TC UC VC cB WC XC YC ZC"},Q:{"4":"aC"},R:{"4":"bC"},S:{"4":"cC"}},B:2,C:"WAI-ARIA Accessibility features"};
