module.exports={A:{A:{"2":"fB","8":"I D E","129":"A B","161":"F"},B:{"1":"N O R S T U V W X P Y Z G","129":"C J K L M"},C:{"1":"0 1 2 3 4 5 6 7 8 9 M N O b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G","2":"gB VB","33":"H a I D E F A B C J K L iB jB"},D:{"1":"0 1 2 3 4 5 6 7 8 9 s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB","33":"H a I D E F A B C J K L M N O b c d e f g h i j k l m n o p q r"},E:{"1":"F A B C J K rB cB TB UB sB tB uB","33":"H a I D E nB bB oB pB qB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB UB","2":"F vB wB","33":"B C L M N O b c d e xB yB TB dB zB"},G:{"1":"5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC","33":"E bB 0B eB 1B 2B 3B 4B"},H:{"2":"JC"},I:{"1":"G","33":"VB H KC LC MC NC eB OC PC"},J:{"33":"D A"},K:{"1":"B C Q TB dB UB","2":"A"},L:{"1":"G"},M:{"1":"P"},N:{"1":"A B"},O:{"1":"QC"},P:{"1":"H RC SC TC UC VC cB WC XC YC ZC"},Q:{"1":"aC"},R:{"1":"bC"},S:{"1":"cC"}},B:4,C:"CSS3 2D Transforms"};
