module.exports={A:{A:{"2":"I D E F A B fB"},B:{"2":"C J K L M N O","33":"R S T U V W X P Y Z G"},C:{"1":"4 5 6 7 8 9 AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G","2":"0 1 2 3 gB VB H a I D E F A B C J K L M N O b c d e f g h i j k l m n o p q r s t u v w x y z iB jB"},D:{"16":"H a I D E F A B C J K L M N O","33":"0 1 2 3 4 5 6 7 8 9 b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB"},E:{"2":"H a nB bB oB","33":"I D E F A B C J K pB qB rB cB TB UB sB tB uB"},F:{"2":"F B C vB wB xB yB TB dB zB UB","33":"0 1 2 3 4 5 6 7 8 9 L M N O b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB"},G:{"16":"E bB 0B eB 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC"},H:{"2":"JC"},I:{"16":"VB H KC LC MC NC eB OC PC","33":"G"},J:{"16":"D A"},K:{"2":"A B C Q TB dB UB"},L:{"16":"G"},M:{"1":"P"},N:{"16":"A B"},O:{"16":"QC"},P:{"16":"H RC SC TC UC VC cB WC XC YC ZC"},Q:{"33":"aC"},R:{"16":"bC"},S:{"1":"cC"}},B:5,C:"CSS color-adjust"};
