module.exports={A:{A:{"2":"I D E F A B fB"},B:{"1":"C J K L M N O R S T U V W X P Y Z G"},C:{"1":"0 1 2 3 4 5 6 7 8 9 o p q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G","2":"gB VB H a I D E F A B C J K L iB jB","132":"M N O b c d e f g","260":"h i j k l m","516":"n"},D:{"1":"0 1 2 3 4 5 6 7 8 9 q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB","2":"H a I D E F A B C J K L M N O","1028":"b c d e f g h i j k l m n o p"},E:{"1":"F A B C J K rB cB TB UB sB tB uB","2":"H a I D E nB bB oB pB qB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB","2":"F B C vB wB xB yB TB dB zB UB","1028":"L M N O b c"},G:{"1":"5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC","2":"E bB 0B eB 1B 2B 3B 4B"},H:{"2":"JC"},I:{"1":"G","2":"VB H KC LC MC","1028":"NC eB OC PC"},J:{"2":"D A"},K:{"1":"Q","2":"A B C TB dB UB"},L:{"1":"G"},M:{"1":"P"},N:{"2":"A B"},O:{"1":"QC"},P:{"1":"H RC SC TC UC VC cB WC XC YC ZC"},Q:{"1":"aC"},R:{"1":"bC"},S:{"1":"cC"}},B:6,C:"ES6 Number"};
