module.exports={A:{A:{"1":"A B","2":"I D E F fB"},B:{"1":"C J K L M N O R S T U V W X P Y Z G"},C:{"1":"0 1 2 3 4 5 6 7 8 9 M N O b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G","2":"gB VB iB jB","33":"a I D E F A B C J K L","164":"H"},D:{"1":"0 1 2 3 4 5 6 7 8 9 i j k l m n o p q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB","33":"H a I D E F A B C J K L M N O b c d e f g h"},E:{"1":"D E F A B C J K pB qB rB cB TB UB sB tB uB","33":"I oB","164":"H a nB bB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 L M N O b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB UB","2":"F vB wB","33":"C","164":"B xB yB TB dB zB"},G:{"1":"E 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC","33":"2B","164":"bB 0B eB 1B"},H:{"2":"JC"},I:{"1":"G OC PC","33":"VB H KC LC MC NC eB"},J:{"1":"A","33":"D"},K:{"1":"Q UB","33":"C","164":"A B TB dB"},L:{"1":"G"},M:{"1":"P"},N:{"1":"A B"},O:{"1":"QC"},P:{"1":"H RC SC TC UC VC cB WC XC YC ZC"},Q:{"1":"aC"},R:{"1":"bC"},S:{"1":"cC"}},B:5,C:"CSS3 Transitions"};
