module.exports={A:{A:{"2":"I D E F A B fB"},B:{"2":"C J K L M N O","322":"R S T U V W X P Y Z G"},C:{"2":"gB VB H a I D E F A B C J K L M N O b c d e f g h i j k l m n o p q iB jB","194":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G"},D:{"2":"0 1 2 3 4 5 6 7 8 H a I D E F A B C J K L M N O b c d e f g h i j k l m n o p q r s t u v w x y z","322":"9 AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB"},E:{"2":"H a I D E F A B C J K nB bB oB pB qB rB cB TB UB sB tB uB"},F:{"2":"F B C L M N O b c d e f g h i j k l m n o p q r s t u v vB wB xB yB TB dB zB UB","322":"0 1 2 3 4 5 6 7 8 9 w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB"},G:{"2":"E bB 0B eB 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC"},H:{"2":"JC"},I:{"2":"VB H G KC LC MC NC eB OC PC"},J:{"2":"D A"},K:{"2":"A B C Q TB dB UB"},L:{"1":"G"},M:{"2":"P"},N:{"2":"A B"},O:{"2":"QC"},P:{"1":"RC SC TC UC VC cB WC XC YC ZC","2":"H"},Q:{"322":"aC"},R:{"1":"bC"},S:{"194":"cC"}},B:5,C:"ImageCapture API"};
