module.exports={A:{A:{"2":"I D E F fB","8":"A B"},B:{"1":"R S T U V W X P Y Z G","578":"C J K L M N O"},C:{"1":"8 9 O b c d e f g AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G","2":"gB VB iB jB","4":"H a I D E F A B C J K L M N","194":"0 1 2 3 4 5 6 7 h i j k l m n o p q r s t u v w x y z"},D:{"1":"0 1 2 3 4 5 6 7 8 9 e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB","2":"H a I D E F A B C J K L M N O b c d"},E:{"2":"H a I D E F A B C J K nB bB oB pB qB rB cB TB UB sB tB uB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 L M N O b c d e f g h i j k l m n o p q r s t u v w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB","2":"F B C vB wB xB yB TB dB zB UB"},G:{"1":"E bB 0B eB 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC"},H:{"2":"JC"},I:{"1":"VB H G KC LC MC NC eB OC PC"},J:{"1":"D A"},K:{"1":"B C Q TB dB UB","2":"A"},L:{"1":"G"},M:{"1":"P"},N:{"8":"A","260":"B"},O:{"1":"QC"},P:{"1":"H RC SC TC UC VC cB WC XC YC ZC"},Q:{"1":"aC"},R:{"1":"bC"},S:{"2":"cC"}},B:2,C:"Touch events"};
