module.exports={A:{A:{"2":"I D E F A B fB"},B:{"1":"C J K L M N O R S T U V W X P Y Z G"},C:{"1":"0 1 2 3 4 5 6 7 8 9 y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G","2":"gB VB H a I D E F A B C J K L M iB jB","129":"s t u v w x","420":"N O b c d e f g h i j k l m n o p q r"},D:{"1":"9 AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB","2":"H a I D E F A B C J K L M N O b c","420":"0 1 2 3 4 5 6 7 8 d e f g h i j k l m n o p q r s t u v w x y z"},E:{"1":"B C J K TB UB sB tB uB","2":"H a I D E F A nB bB oB pB qB rB cB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB","2":"F B L M N vB wB xB yB TB dB zB","420":"C O b c d e f g h i j k l m n o p q r s t u v UB"},G:{"2":"E bB 0B eB 1B 2B 3B 4B 5B 6B 7B 8B","513":"GC HC IC","1537":"9B AC BC CC DC EC FC"},H:{"2":"JC"},I:{"1":"G","2":"VB H KC LC MC NC eB OC PC"},J:{"2":"D","420":"A"},K:{"1":"Q","2":"A B TB dB","420":"C UB"},L:{"1":"G"},M:{"1":"P"},N:{"2":"A B"},O:{"1":"QC"},P:{"1":"SC TC UC VC cB WC XC YC ZC","420":"H RC"},Q:{"1":"aC"},R:{"420":"bC"},S:{"2":"cC"}},B:4,C:"getUserMedia/Stream API"};
